Class: ConceptQL::Nodes::First
- Inherits:
-
Occurrence
- Object
- Node
- Occurrence
- ConceptQL::Nodes::First
- Defined in:
- lib/conceptql/nodes/first.rb
Overview
Represents a node that will grab the first occurrence of something
The node treats all streams as a single, large stream. It partitions that larget stream by person_id, then sorts within those groupings by start_date and then select at most one row per person, regardless of how many different types of streams enter the node
If two rows have the same start_date, the order of their ranking is arbitrary
If we ask for the first occurrence of something and a person has no occurrences, this node returns nothing for that person
Constant Summary
Constants inherited from Node
Instance Attribute Summary
Attributes inherited from Node
Instance Method Summary collapse
Methods inherited from Occurrence
Methods inherited from Node
#arguments, #children, #columns, #date_columns, #evaluate, #initialize, #select_it, #stream, #types
Constructor Details
This class inherits a constructor from ConceptQL::Nodes::Node
Instance Method Details
#occurrence ⇒ Object
18 19 20 |
# File 'lib/conceptql/nodes/first.rb', line 18 def occurrence 1 end |