Class: ConceptQL::Nodes::PlaceOfServiceCode
- Defined in:
- lib/conceptql/nodes/place_of_service_code.rb
Overview
Represents a node that will grab all person rows that match the given place_of_service_codes
PlaceOfServiceCode parameters are passed in as a set of strings. Each string represents a single place_of_service_code. The place_of_service_code string must match one of the values in the concept_name column of the concept table. If you misspell the place_of_service_code name you won’t get any matches
Constant Summary
Constants inherited from Node
Instance Attribute Summary
Attributes inherited from Node
Instance Method Summary collapse
Methods inherited from Node
#arguments, #children, #columns, #date_columns, #evaluate, #initialize, #select_it, #stream
Constructor Details
This class inherits a constructor from ConceptQL::Nodes::Node
Instance Method Details
#query(db) ⇒ Object
16 17 18 19 20 |
# File 'lib/conceptql/nodes/place_of_service_code.rb', line 16 def query(db) db.from(:visit_occurrence_with_dates___v) .join(:vocabulary__concept___vc, { vc__concept_id: :v__place_of_service_concept_id }) .where(vc__concept_code: arguments.map(&:to_s)) end |
#types ⇒ Object
12 13 14 |
# File 'lib/conceptql/nodes/place_of_service_code.rb', line 12 def types [:visit_occurrence] end |